@@ -47,6 +47,7 @@
 #endif
 
 SDL3_SYM_VARARGS(bool,SetError,(SDL_PRINTF_FORMAT_STRING const char *a, ...))
+SDL3_SYM(bool,SetErrorV,(SDL_PRINTF_FORMAT_STRING const char *a, va_list b),(a,b),return);
 SDL3_SYM_VARARGS(void,Log,(SDL_PRINTF_FORMAT_STRING const char *a, ...))
 SDL3_SYM_VARARGS(void,LogVerbose,(int a, SDL_PRINTF_FORMAT_STRING const char *b, ...))
 SDL3_SYM_VARARGS(void,LogDebug,(int a, SDL_PRINTF_FORMAT_STRING const char *b, ...))
@@ -139,6 +140,7 @@ SDL3_SYM(SDL_AudioStream*,CreateAudioStream,(const SDL_AudioSpec *a, const SDL_A
 SDL3_SYM(SDL_Cursor*,CreateColorCursor,(SDL_Surface *a, int b, int c),(a,b,c),return)
 SDL3_SYM_RENAMED(SDL_Condition*,CreateCond,CreateCondition,(void),(),return)
 SDL3_SYM_PASSTHROUGH(SDL_Cursor*,CreateCursor,(const Uint8 *a, const Uint8 *b, int c, int d, int e, int f),(a,b,c,d,e,f),return)
+SDL3_SYM(SDL_Environment*,CreateEnvironment,(bool a),(a),return)
 SDL3_SYM(int,CreateHapticEffect,(SDL_Haptic *a, const SDL_HapticEffect *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH(SDL_Mutex*,CreateMutex,(void),(),return)
 SDL3_SYM(SDL_Window*,CreatePopupWindow,(SDL_Window *a, int b, int c, int d, int e, SDL_WindowFlags f),(a,b,c,d,e,f),return)
@@ -159,6 +161,7 @@ SDL3_SYM(void,RemoveHintCallback,(const char *a, SDL_HintCallback b, void *c),(a
 SDL3_SYM_PASSTHROUGH(void,Delay,(Uint32 a),(a),)
 SDL3_SYM(void,DestroyAudioStream,(SDL_AudioStream *a),(a),)
 SDL3_SYM_RENAMED(void,DestroyCond,DestroyCondition,(SDL_Condition *a),(a),)
+SDL3_SYM(void,DestroyEnvironment,(SDL_Environment *a),(a),)
 SDL3_SYM_PASSTHROUGH(void,DestroyMutex,(SDL_Mutex *a),(a),)
 SDL3_SYM(void,DestroyPalette,(SDL_Palette *a),(a),)
 SDL3_SYM(void,DestroyProperties,(SDL_PropertiesID a),(a),)
@@ -250,6 +253,8 @@ SDL3_SYM(SDL_AudioDeviceID*,GetAudioRecordingDevices,(int *a),(a),return)
 SDL3_SYM(int,GetAudioStreamAvailable,(SDL_AudioStream *a),(a),return)
 SDL3_SYM(int,GetAudioStreamData,(SDL_AudioStream *a, void *b, int c),(a,b,c),return)
 SDL3_SYM(SDL_AudioDeviceID,GetAudioStreamDevice,(SDL_AudioStream *a),(a),return)
+SDL3_SYM(bool,GetAudioStreamFormat,(SDL_AudioStream *a, SDL_AudioSpec *b, SDL_AudioSpec *c),(a,b,c),return)
+SDL3_SYM(SDL_PropertiesID,GetAudioStreamProperties,(SDL_AudioStream *a),(a),return)
 SDL3_SYM(const char*,GetBasePath,(void),(),return)
 SDL3_SYM(bool,GetBooleanProperty,(SDL_PropertiesID a, const char *b, bool c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH(int,GetCPUCacheLineSize,(void),(),return)
@@ -273,6 +278,9 @@ SDL3_SYM(SDL_DisplayID,GetDisplayForWindow,(SDL_Window *a),(a),return)
 SDL3_SYM(const char*,GetDisplayName,(SDL_DisplayID a),(a),return)
 SDL3_SYM(bool,GetDisplayUsableBounds,(SDL_DisplayID a, SDL_Rect *b),(a,b),return)
 SDL3_SYM(SDL_DisplayID*,GetDisplays,(int *a),(a),return)
+SDL3_SYM(SDL_Environment*,GetEnvironment,(void),(),return)
+SDL3_SYM(const char*,GetEnvironmentVariable,(SDL_Environment *a, const char *b),(a,b),return)
+SDL3_SYM(char**,GetEnvironmentVariables,(SDL_Environment *a),(a),return)
 SDL3_SYM_PASSTHROUGH(const char*,GetError,(void),(),return)
 SDL3_SYM(bool,GetEventFilter,(SDL_EventFilter *a, void **b),(a,b),)
 SDL3_SYM(float,GetFloatProperty,(SDL_PropertiesID a, const char *b, float c),(a,b,c),return)
@@ -353,6 +361,7 @@ SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetRenderDrawBlendMode,(SDL_Renderer *a, SDL_B
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetRenderDrawColor,(SDL_Renderer *a, Uint8 *b, Uint8 *c, Uint8 *d, Uint8 *e),(a,b,c,d,e),return)
 SDL3_SYM(const char *,GetRenderDriver,(int a),(a),return);
 SDL3_SYM(bool,GetRenderLogicalPresentation,(SDL_Renderer *a, int *b, int *c, SDL_RendererLogicalPresentation *d),(a,b,c,d),return)
+SDL3_SYM(bool,GetRenderLogicalPresentationRect,(SDL_Renderer *a, SDL_FRect *b),(a,b),return)
 SDL3_SYM(bool,GetRenderScale,(SDL_Renderer *a, float *b, float *c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH(SDL_Texture*,GetRenderTarget,(SDL_Renderer *a),(a),return)
 SDL3_SYM(bool,GetRenderViewport,(SDL_Renderer *a, SDL_Rect *b),(a,b),return)
@@ -368,6 +377,7 @@ SDL3_SYM(SDL_Sensor*,GetSensorFromID,(SDL_SensorID a),(a),return)
 SDL3_SYM(SDL_SensorID,GetSensorID,(SDL_Sensor *a),(a),return)
 SDL3_SYM(const char *,GetSensorNameForID,(SDL_SensorID a),(a),return)
 SDL3_SYM(int,GetSensorNonPortableTypeForID,(SDL_SensorID a),(a),return)
+SDL3_SYM(SDL_PropertiesID,GetSensorProperties,(SDL_Sensor *a),(a),return)
 SDL3_SYM(SDL_SensorType,GetSensorTypeForID,(SDL_SensorID a),(a),return)
 SDL3_SYM(SDL_SensorID *,GetSensors,(int *a),(a),return)
 SDL3_SYM(int,GetSilenceValueForFormat,(SDL_AudioFormat a),(a),return)
@@ -396,6 +406,7 @@ SDL3_SYM(SDL_Finger**,GetTouchFingers,(SDL_TouchID a, int *b),(a,b),return)
 SDL3_SYM(int,GetVersion,(void),(),return)
 SDL3_SYM(const char*,GetVideoDriver,(int a),(a),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetWindowBordersSize,(SDL_Window *a, int *b, int *c, int *d, int *e),(a,b,c,d,e),return)
+SDL3_SYM(float,GetWindowDisplayScale,(SDL_Window *a),(a),return)
 SDL3_SYM(SDL_WindowFlags,GetWindowFlags,(SDL_Window *a),(a),return)
 SDL3_SYM_PASSTHROUGH(SDL_Window*,GetWindowFromID,(Uint32 a),(a),return)
 SDL3_SYM(const SDL_DisplayMode *,GetWindowFullscreenMode,(SDL_Window *a),(a),return)
@@ -516,13 +527,14 @@ SDL3_SYM(void,LockMutex,(SDL_Mutex *a),(a),)
 SDL3_SYM(bool,LockSurface,(SDL_Surface *a),(a),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,LockTexture,(SDL_Texture *a, const SDL_Rect *b, void **c, int *d),(a,b,c,d),return)
 SDL3_SYM(bool,LockTextureToSurface,(SDL_Texture *a, const SDL_Rect *b, SDL_Surface **c),(a,b,c),return)
-SDL3_SYM_RENAMED(void,LogGetOutputFunction,GetLogOutputFunction,(SDL_LogOutputFunction *a, void **b),(a,b),)
+SDL3_SYM(void,GetLogOutputFunction,(SDL_LogOutputFunction *a, void **b),(a,b),)
 SDL3_SYM(SDL_LogPriority,GetLogPriority,(int a),(a),return)
 SDL3_SYM(void,LogMessageV,(int a, SDL_LogPriority b, const char *c, va_list d),(a,b,c,d),)
 SDL3_SYM_RENAMED(void,LogResetPriorities,ResetLogPriorities,(void),(),)
 SDL3_SYM(void,SetLogPriorities,(SDL_LogPriority a),(a),)
-SDL3_SYM_RENAMED(void,LogSetOutputFunction,SetLogOutputFunction,(SDL_LogOutputFunction a, void *b),(a,b),)
+SDL3_SYM(void,SetLogOutputFunction,(SDL_LogOutputFunction a, void *b),(a,b),)
 SDL3_SYM(void,SetLogPriority,(int a, SDL_LogPriority b),(a,b),)
+SDL3_SYM(SDL_LogOutputFunction,GetDefaultLogOutputFunction,(void),(),return)
 SDL3_SYM(Uint32,MapRGB,(const SDL_PixelFormatDetails *a, const SDL_Palette *b, Uint8 c, Uint8 d, Uint8 e),(a,b,c,d,e),return)
 SDL3_SYM(Uint32,MapRGBA,(const SDL_PixelFormatDetails *a, const SDL_Palette *b, Uint8 c, Uint8 d, Uint8 e, Uint8 f),(a,b,c,d,e,f),return)
 SDL3_SYM(bool,MaximizeWindow,(SDL_Window *a),(a),return)
@@ -606,8 +618,10 @@ SDL3_SYM(bool,SetAudioStreamPutCallback,(SDL_AudioStream *a, SDL_AudioStreamCall
 SDL3_SYM(bool,SetBooleanProperty,(SDL_PropertiesID a, const char *b, bool c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,SetClipboardText,(const char *a),(a),return)
 SDL3_SYM(bool,SetCursor,(SDL_Cursor *a),(a),return)
+SDL3_SYM(bool,SetEnvironmentVariable,(SDL_Environment *a, const char *b, const char *c, bool d),(a,b,c,d),return)
 SDL3_SYM(void,SetEventEnabled,(Uint32 a, bool b),(a,b),)
 SDL3_SYM(void,SetEventFilter,(SDL_EventFilter a, void *b),(a,b),)
+SDL3_SYM(bool,SetFloatProperty,(SDL_PropertiesID a, const char *b, float c),(a,b,c),return)
 SDL3_SYM(void,SetGamepadEventsEnabled,(bool a),(a),)
 SDL3_SYM(bool,SetGamepadPlayerIndex,(SDL_GameController *a, int b),(a,b),return)
 SDL3_SYM(bool,SetHint,(const char *a, const char *b),(a,b),return)
@@ -665,6 +679,7 @@ SDL3_SYM(bool,SetWindowResizable,(SDL_Window *a, bool b),(a,b),return)
 SDL3_SYM(bool,SetWindowShape,(SDL_Window *a, SDL_Surface *b),(a,b),return)
 SDL3_SYM(bool,SetWindowSize,(SDL_Window *a, int b, int c),(a,b,c),return)
 SDL3_SYM(bool,SetWindowTitle,(SDL_Window *a, const char *b),(a,b),return)
+SDL3_SYM(void,SetX11EventHook,(SDL_X11EventHook a, void *b),(a,b),return)
 SDL3_SYM(bool,ShowCursor,(void),(),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,ShowMessageBox,(const SDL_MessageBoxData *a, int *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,ShowSimpleMessageBox,(Uint32 a, const char *b, const char *c, SDL_Window *d),(a,b,c,d),return)
@@ -689,6 +704,7 @@ SDL3_SYM(bool,UnlockAudioStream,(SDL_AudioStream *a),(a),return)
 SDL3_SYM(void,UnlockMutex,(SDL_Mutex *a),(a),)
 SDL3_SYM(void,UnlockSurface,(SDL_Surface *a),(a),)
 SDL3_SYM_PASSTHROUGH(void,UnlockTexture,(SDL_Texture *a),(a),)
+SDL3_SYM(bool,UnsetEnvironmentVariable,(SDL_Environment *a, const char *b),(a,b),return)
 SDL3_SYM(bool,UpdateHapticEffect,(SDL_Haptic *a, int b, const SDL_HapticEffect *c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,UpdateNVTexture,(SDL_Texture *a, const SDL_Rect *b, const Uint8 *c, int d, const Uint8 *e, int f),(a,b,c,d,e,f),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,UpdateTexture,(SDL_Texture *a, const SDL_Rect *b, const void *c, int d),(a,b,c,d),return)
@@ -803,7 +819,7 @@ SDL3_SYM_PASSTHROUGH(double,round,(double a),(a),return)
 SDL3_SYM_PASSTHROUGH(float,roundf,(float a),(a),return)
 SDL3_SYM_PASSTHROUGH(double,scalbn,(double a, int b),(a,b),return)
 SDL3_SYM_PASSTHROUGH(float,scalbnf,(float a, int b),(a,b),return)
-SDL3_SYM_RENAMED(int,setenv,setenv_unsafe,(const char *a, const char *b, int c),(a,b,c),return)
+SDL3_SYM(int,setenv_unsafe,(const char *a, const char *b, int c),(a,b,c),return)
 SDL3_SYM_PASSTHROUGH(double,sin,(double a),(a),return)
 SDL3_SYM_PASSTHROUGH(float,sinf,(float a),(a),return)
 SDL3_SYM_PASSTHROUGH(double,sqrt,(double a),(a),return)
